#ifndef UART_H
#define UART_H

#include <avr/pgmspace.h>
#include <stdio.h>

//***********
//* defines *
//***********

#define F_OSC 3686400UL

// Buffergren
#define UART_RX_BUFFER_SIZE	32		// Empfangsbuffer in Byte
#define UART_TX_BUFFER_SIZE	32		// Sendebuffer in Byte

// Baudrate
#define UART_BAUDRATE		115200UL

// USART Hardware Register
#define UART_UCSRA			UCSR1A
#define UART_UCSRB			UCSR1B
#define UART_UCSRC			UCSR1C
#define UART_UBRR			UBRR1L
#define UART_UDR			UDR1

// Interrupt-Namen
#define UART_RECV_IRQ	SIG_UART1_RECV		// Receive Complete Interrupt
#define UART_TRANS_IRQ	SIG_UART1_DATA		// Data Register Empty Interrupt

// Flags
#define UART_ECHO		5		// Empfangene Zeichen werden geechot
#define UART_RECV		6		// Flag wird gesetzt, wenn eine vollstndige
								//  Nachricht im Empfangsbuffer liegt.
								//  Wird in extUartParseMsg() gelscht.
#define UART_BUF_OV		7		// Overflow-Flag


//*********************
//* Gloable Variablen *
//*********************
extern FILE* uartIO;
extern volatile uint8_t uartFlags;
extern uint16_t uartTimeout;


//************************
//* Funktions-Prototypen *
//************************
int  uartGet(void);					// liest ein Zeichen
int  uartPut(char c);				// schreibt ein Zeichen
void uartInit(void);				// initialisiert das UART
void uartFlushRxBuffer(void);	// Verwirft den RxBuffer
void uartFlushTxBuffer(void);	// Verwirft den TxBuffer
void uartDisable(void);			// Deaktiviert das UART

#define uartPuts(str) {fputs(str, uartIO);}
#define uartPutsP(str) {fputs_P(PSTR(str), uartIO);}
#define uartSetTimeout(to) {uartTimeout=to;}

#endif
